.. image:: https://travis-ci.org/MacHu-GWU/windtalker-project.svg?branch=master
    :target: https://travis-ci.org/MacHu-GWU/windtalker-project?branch=master

.. image:: https://codecov.io/gh/MacHu-GWU/windtalker-project/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/MacHu-GWU/windtalker-project

.. image:: https://img.shields.io/pypi/v/windtalker.svg
    :target: https://pypi.python.org/pypi/windtalker

.. image:: https://img.shields.io/pypi/l/windtalker.svg
    :target: https://pypi.python.org/pypi/windtalker

.. image:: https://img.shields.io/pypi/pyversions/windtalker.svg
    :target: https://pypi.python.org/pypi/windtalker

.. image:: https://img.shields.io/badge/Star_Me_on_GitHub!--None.svg?style=social
    :target: https://github.com/MacHu-GWU/windtalker-project


Welcome to ``windtalker`` Documentation
==============================================================================

In World War II, US Marine specially recruited a lots of bilingual Navajo speakers to serve in their standard communications units in the Pacific Theater. These Navajo transmitted tactical messages over military telephone or radio communications nets using formal or informally developed codes built upon their native languages. These people, we call them --- **Wind Talker**

``windtalker`` is a utility tools built on top of `cryptography <https://pypi.python.org/pypi/cryptography>`_ and `rsa <https://pypi.python.org/pypi/rsa>`_. With this, **you can encrypt/decrypt binary data, text, files or even a entire directory in single line of code**! It support both symmetry and asymmetry encryption algorithm. For usage, you should start from `HERE <http://www.wbh-doc.com.s3.amazonaws.com/windtalker/index.html#id5>`_

Example (SymmtricCipher):

.. code-block:: python

    >>> from windtalker import SymmtricCipher
    >>> c = SymmtricCipher(password="password") # Fernet encrypter
    >>> c.encrypt_text("Hello")
    Z0FBQUFBQlo0VHpVVjdWR0xCb0VEc0dMVUxib25jZEwzTWZ1UC1raFVmWndwNERrTmZVR1hNdzE3ZS05RWkwWXBrTi1adUhRWTNWYkxUT1Vkekh3MlVVcHZXLWxaMWMyOEE9PQ==

    >>> c.encrypt_file(r"C:\test.py") # c.decrypt_file(xxx) for decryption
    C:\test-encrypted.py

    >>> c.encrypt_dir(r"C:\User\Admin\Document") # c.decrypt_dir(xxx) for decryption
    C:\User\Admin\Document-encrypted.py


Quick Links
------------------------------------------------------------------------------

- .. image:: https://img.shields.io/badge/Link-Document-red.svg
      :target: http://www.wbh-doc.com.s3.amazonaws.com/windtalker/index.html

- .. image:: https://img.shields.io/badge/Link-API_Reference_and_Source_Code-red.svg
      :target: http://www.wbh-doc.com.s3.amazonaws.com/windtalker/py-modindex.html

- .. image:: https://img.shields.io/badge/Link-Install-red.svg
      :target: `install`_

- .. image:: https://img.shields.io/badge/Link-GitHub-blue.svg
      :target: https://github.com/MacHu-GWU/windtalker-project

- .. image:: https://img.shields.io/badge/Link-Submit_Issue_and_Feature_Request-blue.svg
      :target: https://github.com/MacHu-GWU/windtalker-project/issues

- .. image:: https://img.shields.io/badge/Link-Download-blue.svg
      :target: https://pypi.python.org/pypi/windtalker#downloads


.. _install:

Install
------------------------------------------------------------------------------

``windtalker`` is released on PyPI, so all you need is:

.. code-block:: console

    $ pip install windtalker

To upgrade to latest version:

.. code-block:: console

    $ pip install --upgrade windtalker